<?php // Avoid subscribe links display on meta section ?>
<?php if (function_exists("the_subscribe_links")) define('sem_subscribe_me_displayed', true); ?>

	<div id="sidebar">
				<div id="sidebar-col1" class="sidebar-column">
		
					<ul id="sidebar-1">
			
					<?php if ( !function_exists('dynamic_sidebar') || !dynamic_sidebar(1) ) : ?>

						<?php
						widget_execute_standalone("widget_about_this_page","About this page"); 
						widget_execute_standalone("widget_search_with_nav","Search with navigation"); 
						widget_execute_standalone("widget_pages_list","Fixed-depth page list"); 
						widget_execute_standalone("widget_calendar_archives","Calendar with archives link"); 
						if (function_exists("widget_gallery2_sidebar"))
							widget_execute_standalone("widget_gallery2_sidebar","WP-Gallery2 thumbnails"); 
						widget_execute_standalone("widget_about_this_site","About this site");
						?>

					<?php endif; ?>
			
					</ul>
		
				</div>

				<div id="sidebar-col3" class="sidebar-column">

					<ul id="sidebar-2">

					<?php if ( !function_exists('dynamic_sidebar') || !dynamic_sidebar(2) ) : ?>
			
						<?php
						if (function_exists('widget_wordspew'))
							widget_execute_standalone("widget_wordspew","Rudd-O's Wordspew"); 
						 widget_execute_standalone("widget_subscribe","Join us and subscribe"); 
						if (function_exists('widget_related_posts'))
							widget_execute_standalone("widget_related_posts","Related posts"); 
						
						if (function_exists('widget_recent_comments_with_excerpts'))
							 widget_execute_standalone("widget_recent_comments_with_excerpts","Recent comments with excerpts");
						elseif (function_exists('widget_recent_comments'))
							widget_execute_standalone("widget_recent_comments","Recent Comments");
						 
						if (function_exists('widget_popular_posts'))
							widget_execute_standalone("widget_popular_posts","Popular posts"); 
						if (function_exists('widget_dates_to_remember'))
							widget_execute_standalone("widget_dates_to_remember","Upcoming events"); 
						get_links_list();
						if (function_exists('widget_wp_theme_switcher')) 
							widget_execute_standalone("widget_wp_theme_switcher","Theme switcher");
						?>
			
					<?php endif; ?>

					</ul>

				</div>
	</div>
