/*
Theme Name: Burnin' R
Theme URI: http://rudd-o.com/projects/burninr/
Description: A hot new fluid theme from Rudd-O.  Please follow the instructions in the included README file after activating this theme.
Version: 2.0.4
Author: Manuel Amador (Rudd-O)
Author URI: http://rudd-o.com/
*/

@import url(utility-styles.css);
@import url(ad-styles.css);
@import url(common.css);
@import url(colors-classic.css);
