/* color palette */
/* lifted hackishly from revvedup thanks to kcolorchooser */
/*
page background color: #f1f1fb;
default text color: black;
links : #0000b8;
visited links: #7d2a27;
sidebar background: #e1e0f7;
block quote / pre text: black
block quote / pre borders: #f1f1fb;
post metadata / slugs / comment metadata: #999999;
text for comments: black
top border for sidebar and border for navigation controls placed in content: #f1f1fb;
border for sidebar: none
border for sidebar LI buttons: #f1f1fb;
border for sidebar LI light border: #ef7581;
background for tooltips: #e1e0f7;
*/

@media screen {
	#header {
		background-color: #f1f1fb;
		height: 138px;
		margin-top: 20px;
		border-right: 1px solid #0000b8;
		border-left: 1px solid #0000b8;
		border-top: 1px solid #0000b8;
		-moz-border-radius-topright: 10px;
		-moz-border-radius-topleft: 10px;
	}
	#header .corner-deco {
		display: none;
	}
	#header .description {
		display: block;
		text-align: center;
		color: #0000b8;
	}
	#header h1 {text-align: center;font-size: 400%; font-style: italic; margin-top: 0.5em; margin-bottom: 0}
	#header h1 a {text-decoration: none;}
	#page { /*where the background image is placed*/
		background-color: #f1f1fb;
		border-right: 1px solid #0000b8;
		border-left: 1px solid #0000b8;
		border-bottom: 1px solid #0000b8;
	}

}

a:link, a:active {
	color: #0000b8;
}

a:visited {
	color: #3333ff;
}
abbr, acronym { border-bottom: 1px dashed #f1f1fb; }
code { background: #f1f1fb; }

hr {
	background-color: #f1f1fb;
}
blockquote, pre {
	background: #f1f1fb;
	border: 1px dashed #f1f1fb;
}

#content .post + .navigation { /* on navigation controls after a post we place top/bottom borders */ 
	border-top: 2px solid #f1f1fb;
	border-bottom: 2px solid #f1f1fb;
}

.commentlist>li {
	border: 1px outset #f1f1fb;
}

.commentlist li.alt {
	background: #f1f1fb;
	border: 1px outset #f1f1fb;
}

ul.boxmeup li,
#fixed-depth-page-list ul li,
#about-this-site ul li,
#archives ul li,
.pagenav ul li,
#popular-posts ul li,
#meta ul li,
#related-posts ul li,
#recent-comments ul li,
#recent-posts ul li,
#categories ul li,
#delicious-links ul li,
#linkcat-1 ul li,#linkcat-2 ul li,#linkcat-3 ul li,#linkcat-4 ul li,#linkcat-5 ul li,
#linkcat-6 ul li,#linkcat-7 ul li,#linkcat-8 ul li,#linkcat-9 ul li,#linkcat-10 ul li,
#rss-1 ul li, #rss-2 ul li, #rss-3 ul li, #rss-4 ul li, #rss-5 ul li,
#recent-comments-with-excerpts ul li
{
	border-top: 1px solid #f1f1fb;
	border-bottom: 1px solid #0000b8;
}

ul.boxmeup li:hover,
#fixed-depth-page-list ul li:hover,
#about-this-site ul li:hover,
#archives ul li:hover,
.pagenav ul li:hover,
#popular-posts ul li:hover,
#meta ul li:hover,
#related-posts ul li:hover,
#recent-comments ul li:hover,
#recent-posts ul li:hover,
#categories ul li:hover,
#delicious-links ul li:hover,
#linkcat-1 ul li:hover,#linkcat-2 ul li:hover,#linkcat-3 ul li:hover,#linkcat-4 ul li:hover,#linkcat-5 ul li:hover,
#linkcat-6 ul li:hover,#linkcat-7 ul li:hover,#linkcat-8 ul li:hover,#linkcat-9 ul li:hover,#linkcat-10 ul li:hover,
#rss-1 ul li:hover,#rss-2 ul li:hover,#rss-3 ul li:hover,#rss-4 ul li:hover,#rss-5 ul li:hover,
#recent-comments-with-excerpts ul li:hover
{
	background-color: #f1f1fb;
	border-bottom: 1px solid #f1f1fb;
}

ul.boxmeup li:hover ul li
#fixed-depth-page-list ul li:hover ul li,
#meta ul li:hover ul li,
#categories ul li:hover ul li,
.pagenav ul li:hover ul li,
#about-this-site ul li:hover ul li
{ /* using this we remove the annoying black lines */
	border-top: 1px solid #f1f1fb;
	border-bottom: 1px solid #f1f1fb;
}

ul.boxmeup li:hover ul li:hover,
#fixed-depth-page-list ul li:hover ul li:hover,
#meta ul li:hover ul li:hover,
#categories ul li:hover ul li:hover,
.pagenav ul li:hover ul li:hover,
#about-this-site ul li:hover ul li:hover
{
	background-color: #e1e0f7;
	border-top: 1px solid #0000b8;
	border-bottom: 1px solid black;
}

#sidebar {
	color: black;
}

#sidebar-col1, #sidebar-col3 {
	background: #e1e0f7;
}

#sidebar h2 {
	color: #0000b8;
}

#calendar-with-archives-link #calendar-container, #sidebar li#calendar {
	background: #f1f1fb;
	border: 1px inset #f1f1fb;
}

#calendar-with-archives-link #wp-calendar #today, #sidebar #wp-calendar #today {
	border: 1px outset #e1e0f7;
	background: #e1e0f7;
}

#calendar-with-archives-link #wp-calendar caption , #wp-calendar caption {
	border: 1px outset #f1f1fb;
	background: #e1e0f7;
}

.themed div.fancytooltip {
	color: black;
	background-color: #e1e0f7;
}
.themed #bstat_pulse img {
	background: #f1f1fb;
	border-top: 1px solid #f1f1fb;
	border-bottom: 1px solid #f1f1fb;
}
.themed #bstat_pulse img:hover { /* kewl animation on mouseover */
	border-left: 1px solid #f1f1fb;
	border-right: 1px solid #f1f1fb;
}
.themed .bstat_hilite {
	border: 1px dashed #f1f1fb;
}

.themed #chatoutput {
	background: #f1f1fb;
	border-top: 1px inset #f1f1fb;
	border-left: 1px inset #f1f1fb;
}

.themed #chatoutput #lastMessage { border-bottom: 3px dotted #e1e0f7; }
.themed #chatoutput span, .themed #chatoutput a {color: black;} /* override colors */
.themed #chatoutput, .themed #chatoutput ul#outputList li {color: black;} /* override colors */
