/* color palette */
/*
page background color: #c70518;
default text color: black;
links : #c70518;
visited links: #7d2a27;
sidebar background: #8c000e;
block quote / pre text: black
block quote / pre borders: #c70518;
post metadata / slugs / comment metadata: #999999;
text for comments: black
top border for sidebar and border for navigation controls placed in content: #c70518;
border for sidebar: none
border for sidebar LI buttons: #c70518;
border for sidebar LI light border: #ef7581;
background for tooltips: #8c000e;
*/

@media screen {
	#header {
		background-color: #c70518;
		background-image: url(images/header-background.png);
		height: 158px;
		border-right: 1px solid black;
		border-left: 1px solid black;
	}
	#header .corner-deco {
		display: block;
		height: 60px;
		width: 60px;
		position: absolute;
	}
	#header .floatright {
		right: 17px;
		top: 0px;
		background: url(images/header-right-corner.png);
		background-position: top right;
		background-repeat: no-repeat;
	}
	#header .floatleft {
		left: 17px;
		top: 0px;
		background: url(images/header-left-corner.png);
		background-position: top left;
		background-repeat: no-repeat;
	}
	#headerimg {
		background-image: url(images/header-logo.jpg);
		background-position: top center;
		background-repeat: no-repeat;
		height: 158px;
	}
	#header .description {
		position: absolute;
		left: 55%;
		top: 142px;
		color: white;
	}
	#header h1 {display: none;} /* hide the header in screen displays */
	#page { /*where the background image is placed*/
		background-color: #c70518;
		border-right: 1px solid black;
		border-left: 1px solid black;
		border-bottom: 1px solid black;
	}
	#content {
		min-height: 385px; /* for the R watermark */
		background-image: url(images/content-background.png);
		background-repeat: no-repeat;
		background-attachment: fixed;
		background-position: center 170px;
	}

}

a:link, a:active {
	color: #c70518;
}

a:visited {
	color: #7d2a27;
}
abbr, acronym { border-bottom: 1px dashed #c70518; }
code { background: url(images/semitransparent-red.png); }

hr {
	background-color: #c70518;
}
blockquote, pre {
	background: url(images/semitransparent-red.png);
	border: 1px dashed #c70518;
}

#content .post + .navigation { /* on navigation controls after a post we place top/bottom borders */ 
	border-top: 2px solid #c70518;
	border-bottom: 2px solid #c70518;
}

.commentlist>li {
	border: 1px outset #c70518;
}

.commentlist li.alt {
	background: url(images/semitransparent-red.png);
	border: 1px outset #c70518;
}

ul.boxmeup li,
#fixed-depth-page-list ul li,
#about-this-site ul li,
#archives ul li,
.pagenav ul li,
#popular-posts ul li,
#meta ul li,
#related-posts ul li,
#recent-comments ul li,
#recent-posts ul li,
#categories ul li,
#delicious-links ul li,
#linkcat-1 ul li,#linkcat-2 ul li,#linkcat-3 ul li,#linkcat-4 ul li,#linkcat-5 ul li,
#linkcat-6 ul li,#linkcat-7 ul li,#linkcat-8 ul li,#linkcat-9 ul li,#linkcat-10 ul li,
#rss-1 ul li, #rss-2 ul li, #rss-3 ul li, #rss-4 ul li, #rss-5 ul li,
#recent-comments-with-excerpts ul li
{
	border-top: 1px solid #c70518;
	border-bottom: 1px solid black;
}

ul.boxmeup li:hover,
#fixed-depth-page-list ul li:hover,
#about-this-site ul li:hover,
#archives ul li:hover,
.pagenav ul li:hover,
#popular-posts ul li:hover,
#meta ul li:hover,
#related-posts ul li:hover,
#recent-comments ul li:hover,
#recent-posts ul li:hover,
#categories ul li:hover,
#delicious-links ul li:hover,
#linkcat-1 ul li:hover,#linkcat-2 ul li:hover,#linkcat-3 ul li:hover,#linkcat-4 ul li:hover,#linkcat-5 ul li:hover,
#linkcat-6 ul li:hover,#linkcat-7 ul li:hover,#linkcat-8 ul li:hover,#linkcat-9 ul li:hover,#linkcat-10 ul li:hover,
#rss-1 ul li:hover,#rss-2 ul li:hover,#rss-3 ul li:hover,#rss-4 ul li:hover,#rss-5 ul li:hover,
#recent-comments-with-excerpts ul li:hover
{
	background-color: #c70518;
	border-bottom: 1px solid #c70518;
}

ul.boxmeup li:hover ul li
#fixed-depth-page-list ul li:hover ul li,
#meta ul li:hover ul li,
#categories ul li:hover ul li,
.pagenav ul li:hover ul li,
#about-this-site ul li:hover ul li
{ /* using this we remove the annoying black lines */
	border-top: 1px solid #c70518;
	border-bottom: 1px solid #c70518;
}

ul.boxmeup li:hover ul li:hover,
#fixed-depth-page-list ul li:hover ul li:hover,
#meta ul li:hover ul li:hover,
#categories ul li:hover ul li:hover,
.pagenav ul li:hover ul li:hover,
#about-this-site ul li:hover ul li:hover
{
	background-color: #8c000e;
	border-top: 1px solid #ef7581;
	border-bottom: 1px solid black;
}

#sidebar {
	color: white;
}

#sidebar a {
	color: white;
}

#sidebar-col1, #sidebar-col3 {
	background: #8c000e;
}

#calendar-with-archives-link #calendar-container, #sidebar li#calendar {
	background: #c70518;
	border: 1px inset #c70518;
}

#calendar-with-archives-link #wp-calendar #today, #sidebar #wp-calendar #today {
	border: 1px outset #8c000e;
	background: #8c000e;
}

#calendar-with-archives-link #wp-calendar caption , #wp-calendar caption {
	border: 1px outset #c70518;
	background: #8c000e;
}

.themed div.fancytooltip {
	color: white;
	background-color: #8c000e;
}
.themed #bstat_pulse img {
	border: none;
	border-top: 1px solid #c70518;
	border-bottom: 1px solid #c70518;
}
.themed #bstat_pulse img:hover { /* kewl animation on mouseover */
	border-left: 1px solid #c70518;
	border-right: 1px solid #c70518;
}
.themed .bstat_hilite {
	border: 1px dashed #c70518;
}

.themed #chatoutput {
	background: #c70518;
	border-top: 1px inset #c70518;
	border-left: 1px inset #c70518;
}

.themed #chatoutput #lastMessage { border-bottom: 3px dotted #8c000e; }
.themed #chatoutput span, .themed #chatoutput a {color: white;} /* override colors */
.themed #chatoutput, .themed #chatoutput ul#outputList li {color: white ;} /* override colors */
